@@ -107,6 +107,9 @@ elif board_id == ap_board.ORANGE_PI_ZERO_PLUS_2H5:
 elif board_id == ap_board.ORANGE_PI_ZERO_PLUS:
     from adafruit_blinka.board.orangepi.orangepizeroplus import *
 
+elif board_id == ap_board.ORANGE_PI_ZERO_2:
+    from adafruit_blinka.board.orangepi.orangepizero2 import *
+
 elif board_id == ap_board.BANANA_PI_M2_ZERO:
     from adafruit_blinka.board.bananapi.bpim2zero import *
 
@@ -197,6 +200,9 @@ elif board_id == ap_board.LUBANCAT_IMX6ULL:
 elif board_id == ap_board.NANOPI_NEO_AIR:
     from adafruit_blinka.board.nanopi.neoair import *
 
+elif board_id == ap_board.NANOPI_DUO2:
+    from adafruit_blinka.board.nanopi.duo2 import *
+
 elif "sphinx" in sys.modules:
     pass
 
