@@ -69,6 +69,8 @@ elif detector.chip.MT8167:
     from adafruit_blinka.microcontroller.mt8167.pin import Pin
 elif detector.chip.H5:
     from adafruit_blinka.microcontroller.allwinner.h5.pin import Pin
+elif detector.chip.H616:
+    from adafruit_blinka.microcontroller.allwinner.h616.pin import Pin
 
 from adafruit_blinka import Enum, ContextManaged
 
